function G=alege_g(coord,dir,U,stop)
%functie pt alegerea valorilor vector field-ului (g11,...) la virfurile dreptunghiurilor
%vom folosi funcita linprog - minimizare a proiectiei unui vector pe o directie, cu diferite restrictii
%G (de tip cell) va contine, in elemetul i (i=1:nr_d), o matrice cu valorile g11,g21,g22,g12 pt drept i din cale
%coord=matrice cu 4 coloane, cu linii de forma [x1,x2,y1,y2]
%dir=vector linie, care arata in ce directie parasim fiecare dreptunghi
%U-setul convex ce limiteaza vectorii viteza
%stop-coordonatele punctului de stop (pt a alege val. g in ultimul drept.)

nr_d=length(dir);
G=cell(1,nr_d);
l_x=(coord(:,2)-coord(:,1))'; %vector linie ce va contine latimile dreptunghiurilor din cale
l_y=(coord(:,4)-coord(:,3))'; %vector cu inaltimile dreptunghiurilor din cale

%aflara matricei A si a vectorului b a.i. punctul X este in setul convex U <=> AX<=b  (vezi formule deduse in caiet)
nr_vf=size(U,2); %nr de virfuri ale setului U
U=[U U(:,1)]; %"inchidem" setul U; virfurile sint in sens trigonometric
E1=[0 1;-1 0]; %matrice pt calculul mai usor al normalelor
E2=[0 -1;1 0];
A=zeros(nr_vf,2); %matricea A si vectorul b de mai sus
b=zeros(nr_vf,1);
for i=1:nr_vf
    v=(U(:,i+1)-U(:,i))/norm(U(:,i+1)-U(:,i)); %vectorul unitate de directie al laturii (i,i+1)
    n1=E1*v;
    n2=E2*v;
    p1=cross([n1;0],[v;0]); %produsul vectorial (pt a putea alege n - outer normal
    p2=cross([n2;0],[v;0]);
    if p1(3)>0
        n=n1; %outer-normal-ul fetei (i,i+1)
    else
        n=n2;
    end
    A(i,:)=n';
    b(i)=n'*U(:,i);
end
U1=[-1 0;0 -1]; %pt a cauta un punct X in U1 (vezi caiet)
U2=[1 0;0 -1];
U3=[1 0;0 1];
U4=[-1 0;0 1];

opt=optimset('Display','off'); %pt ca functia de optimizare sa nu afiseze nimic

%parcurgerea drept. din cale si alegerea valorilor g la cite 2 colturi pt fiecare dreptunghi
for i=1:nr_d-1
    %pt alegerea valorilor g vom calcula nx,ny - sumele latimilor (resp inaltimilor) parcurse consecutiv in acelasi sens (explicatii in caiet)
    dir_c=dir(i); %directia in care parasim drept. curent
    switch dir_c
        case 1 %parasim drept i spre N
            ny=l_y(i);
            j=i+1;
            while (j<nr_d) & (dir(j)==dir_c)
                ny=ny+l_y(j);
                j=j+1;
            end
            if dir(j)==2 %din drept. j se merge spre W
                d11=-[0;ny];  %g11->maximizare pe directia [0;ny], din setul U1
                d21=-[-l_x(j);ny];
            elseif dir(j)==4 %din drept. j se merge spre E
                d11=-[l_x(j);ny];
                d21=-[0;ny];
            else %dir(j)=0 - drept. tinta
                d11=-[0;ny];
                d21=-[0;ny];
            end
            g11=linprog(d11,[A;U1],[b;0;0],[],[],[],[],[],opt);
            g21=linprog(d21,[A;U2],[b;0;0],[],[],[],[],[],opt);
            G{i}=[g11 g21 [0;0] [0;0]];
        case 2 %parasim drept. spre W
            nx=l_x(i);
            j=i+1;
            while (j<nr_d) & (dir(j)==dir_c)
                nx=nx+l_x(j);
                j=j+1;
            end
            if dir(j)==1 %din drept. j se merge spre N
                d21=-[-nx;l_y(j)];
                d22=-[-nx;0];
            elseif dir(j)==3 %din drept. j se merge spre S
                d21=-[-nx;0];
                d22=-[-nx;-l_y(j)];
            else
                d21=-[-nx;0];
                d22=-[-nx;0];
            end
            g21=linprog(d21,[A;U2],[b;0;0],[],[],[],[],[],opt);
            g22=linprog(d22,[A;U3],[b;0;0],[],[],[],[],[],opt);
            G{i}=[[0;0] g21 g22 [0;0]];
        case 3 %mergem spre S
            ny=l_y(i);
            j=i+1;
            while (j<nr_d) & (dir(j)==dir_c)
                ny=ny+l_y(j);
                j=j+1;
            end
            if dir(j)==2 %din drept. j se merge spre W
                d22=-[-l_x(j);-ny];
                d12=-[0;-ny];
            elseif dir(j)==4 %din drept. j se merge spre E
                d22=-[0;-ny];
                d12=-[l_x(j);-ny];
            else
                d22=-[0;-ny];
                d12=-[0;-ny];
            end
            g22=linprog(d22,[A;U3],[b;0;0],[],[],[],[],[],opt);
            g12=linprog(d12,[A;U4],[b;0;0],[],[],[],[],[],opt);
            G{i}=[[0;0] [0;0] g22 g12];
        case 4 %mergem spre E
            nx=l_x(i);
            j=i+1;
            while (j<nr_d) & (dir(j)==dir_c)
                nx=nx+l_x(j);
                j=j+1;
            end
            if dir(j)==1 %din drept. j se merge spre N
                d11=-[nx;l_y(j)];
                d12=-[nx;0];
            elseif dir(j)==3 %din drept. j se merge spre S
                d11=-[nx;0];
                d12=-[nx;-l_y(j)];
            else
                d11=-[nx;0];
                d12=-[nx;0];
            end
            g11=linprog(d11,[A;U1],[b;0;0],[],[],[],[],[],opt);
            g12=linprog(d12,[A;U4],[b;0;0],[],[],[],[],[],opt);
            G{i}=[g11 [0;0] [0;0] g12];
    end
end

%cautam punctele de schimbare de directie si alegem valorile g in ele
for i=2:nr_d-1
    if dir(i-1)==1 & dir(i)==2 %am intrat in drept i dinspre S si iesim spre W
        G{i}(:,1)=linprog(-[0;1],[A;U1],[b;0;0],[1 0],[0],[],[],[],opt); %g11(i) = valoarea maxima a vitezei din U1 cu v_x=0
        G{i+1}(:,2)=G{i}(:,1);
    elseif dir(i-1)==1 & dir(i)==4
        G{i}(:,2)=linprog(-[0;1],[A;U2],[b;0;0],[1 0],[0],[],[],[],opt);
        G{i+1}(:,1)=G{i}(:,2);
    elseif dir(i-1)==2 & dir(i)==1
        G{i}(:,3)=linprog([1;0],[A;U3],[b;0;0],[0 1],[0],[],[],[],opt);
        G{i+1}(:,2)=G{i}(:,3);
    elseif dir(i-1)==2 & dir(i)==3
        G{i}(:,2)=linprog([1;0],[A;U2],[b;0;0],[0 1],[0],[],[],[],opt);
        G{i+1}(:,3)=G{i}(:,2);
    elseif dir(i-1)==3 & dir(i)==2
        G{i}(:,4)=linprog([0;1],[A;U4],[b;0;0],[1 0],[0],[],[],[],opt);
        G{i+1}(:,3)=G{i}(:,4);
    elseif dir(i-1)==3 & dir(i)==4
        G{i}(:,3)=linprog([0;1],[A;U3],[b;0;0],[1 0],[0],[],[],[],opt);
        G{i+1}(:,4)=G{i}(:,3);
    elseif dir(i-1)==4 & dir(i)==1
        G{i}(:,4)=linprog(-[1;0],[A;U4],[b;0;0],[0 1],[0],[],[],[],opt);
        G{i+1}(:,1)=G{i}(:,4);
    elseif dir(i-1)==4 & dir(i)==3
        G{i}(:,1)=linprog(-[1;0],[A;U1],[b;0;0],[0 1],[0],[],[],[],opt);
        G{i+1}(:,4)=G{i}(:,1);
    end
end
 
%asignarea valorilor g pt ultimul dreptunghi (formulele in caiet)
d11=stop-coord(nr_d,[1 3])'; %directiile lui g11,... (NU directiile de maximizare)
d21=stop-coord(nr_d,[2 3])';
d22=stop-coord(nr_d,[2 4])';
d12=stop-coord(nr_d,[1 4])';

%aflarea valorii scalare lambda maxim (limitat de setul U) (minimul dintre valorile lam. maxime pt g11,...)
lam1=linprog(-d11,[A;U1],[b;0;0],(E1*d11)',[0],[],[],[],opt); %aflam lambda max. pt g11,...
lam1=norm(lam1)/norm(d11);
lam2=linprog(-d21,[A;U2],[b;0;0],(E1*d21)',[0],[],[],[],opt);
lam2=norm(lam2)/norm(d21);
lam3=linprog(-d22,[A;U3],[b;0;0],(E1*d22)',[0],[],[],[],opt);
lam3=norm(lam3)/norm(d22);
lam4=linprog(-d12,[A;U4],[b;0;0],(E1*d12)',[0],[],[],[],opt);
lam4=norm(lam4)/norm(d12);
lam=min([lam1 lam2 lam3 lam4]);
G{nr_d}=lam*[d11 d21 d22 d12];

%parcurgem calea si setam g la virfurile la care nu sint (de la drept. urmator) pt a asigura o traiectorie smooth
for i=2:nr_d
    switch(dir(i-1)) %directia dinspre care am intrat in drept. i
        case 1 %am intrat dinspre S, vom seta g22 si g12 la drept. (i-1) (anterior)
            G{i-1}(:,3)=G{i}(:,2); %g22(i-1)=g21(i)
            G{i-1}(:,4)=G{i}(:,1);
        case 2 %am intrat dinspre E
            G{i-1}(:,1)=G{i}(:,2);
            G{i-1}(:,4)=G{i}(:,3);
        case 3 %dinspre N
            G{i-1}(:,1)=G{i}(:,4);
            G{i-1}(:,2)=G{i}(:,3);
        case 4 %dinspre W
            G{i-1}(:,2)=G{i}(:,1);
            G{i-1}(:,3)=G{i}(:,4);
    end
end

%mutam (daca este cazul) ne-smoothness ul de la penultimul la ultimul drept.
if nr_d>2 & dir(nr_d-2)~=dir(nr_d-1)
    if dir(nr_d-2)==1 & dir(nr_d-1)==2
        G{nr_d-1}(:,1)=G{nr_d-2}(:,4);
    elseif dir(nr_d-2)==1 & dir(nr_d-1)==4
        G{nr_d-1}(:,2)=G{nr_d-2}(:,3);
    elseif dir(nr_d-2)==2 & dir(nr_d-1)==1
        G{nr_d-1}(:,3)=G{nr_d-2}(:,4);
    elseif dir(nr_d-2)==2 & dir(nr_d-1)==3
        G{nr_d-1}(:,2)=G{nr_d-2}(:,1);
    elseif dir(nr_d-2)==3 & dir(nr_d-1)==2
        G{nr_d-1}(:,4)=G{nr_d-2}(:,1);
    elseif dir(nr_d-2)==3 & dir(nr_d-1)==4
        G{nr_d-1}(:,3)=G{nr_d-2}(:,2);
    elseif dir(nr_d-2)==4 & dir(nr_d-1)==1
        G{nr_d-1}(:,4)=G{nr_d-2}(:,3);
    elseif dir(nr_d-2)==4 & dir(nr_d-1)==3
        G{nr_d-1}(:,1)=G{nr_d-2}(:,2);
    end
end
