function [timp,poz,vitez]=traseu(P0,coord,g_virfuri,stop,d_min)
%functie pt gasirea traseului mobilului in dreptunghiul curent, avind valorile vector field-ului la virfuri
%date intrare:
%P0-pozitia initiala (pt. dreptunghiul curent)
%vectorul "coord" contine x1,x2,y1,y2 - coordonatele virfurilor dreptunghiului curent (scalari)
%g_virfuri - matrice cu 2 linii ce contine valorile v.f. la virfurile drept. curent (vectori cu 2 elemente)
%in ordinea: g11-colt stinga-jos, g21-colt dreapta-jos, g22-colt dreapta-sus, g12-colt stinga-sus
%stop-coordonatele punctului de stop
%d_min-distanta minima considerata (pt a ne opri cind sintem in apropierea punctului de stop) 
%ult_dr-daca sintem in ultimul dreptunghi = 1, altfel 0 (se schimba conditia de oprire a integrarii)

%date iesire:
%timp-valorile timpului (relative la drept.) (0 este timpul initial in dreptunghiul curent)
%poz-pozitiile mobilului (matrice cu 2 linii) la momentele din vect. timp
%vitez-viteza mobilului (matrice cu 2 linii) la momentele de timp

x1=coord(1);
x2=coord(2);
y1=coord(3);
y2=coord(4);
coord_dr=[x1 x2 x2 x1;y1 y1 y2 y2]; %coordonatele dreptunghiului

g11=g_virfuri(:,1);
g21=g_virfuri(:,2);
g22=g_virfuri(:,3);
g12=g_virfuri(:,4);

options = odeset('Events',@(t,xy) evenim(t,xy,coord_dr,stop,d_min),'MaxStep',0.5); %eventual si "'Refine',5,", functia evenim va contine conditia de stop a integrarii curente (parasirea drept. curent)

[t,xy]=ode45(@(t,xy) vf(t,xy,x1,x2,y1,y2,g11,g21,g22,g12),[0 Inf],P0,options); %integrarea fara limita de timp a functiei definite de vf (vezi mai jos)

timp=t';
poz=xy';
vitez(1,:)=((x2-poz(1,:)).*(y2-poz(2,:))*g11(1)+(x2-poz(1,:)).*(poz(2,:)-y1)*g12(1)+(poz(1,:)-x1).*(y2-poz(2,:))*g21(1)+(poz(1,:)-x1).*(poz(2,:)-y1)*g22(1))/((x2-x1)*(y2-y1));
vitez(2,:)=((x2-poz(1,:)).*(y2-poz(2,:))*g11(2)+(x2-poz(1,:)).*(poz(2,:)-y1)*g12(2)+(poz(1,:)-x1).*(y2-poz(2,:))*g21(2)+(poz(1,:)-x1).*(poz(2,:)-y1)*g22(2))/((x2-x1)*(y2-y1));


function dxdy=vf(t,xy,x1,x2,y1,y2,g11,g21,g22,g12)
%functie care da valoarea vector field-ului (derivatele in rap cu timpul ale coord.) in punctul curent (cu coordonatele in vect. xy)
dxdy=((x2-xy(1))*(y2-xy(2))*g11+(x2-xy(1))*(xy(2)-y1)*g12+(xy(1)-x1)*(y2-xy(2))*g21+(xy(1)-x1)*(xy(2)-y1)*g22)/((x2-x1)*(y2-y1)); %formula f(x) functie de val la virfuri

function [value,isterminal,direction] = evenim(t,xy,coord_dr,stop,d_min) %functie pt definirea evenimentului de terminare a integrarii
value = double(inpolygon(xy(1),xy(2),coord_dr(1,:),coord_dr(2,:)) & norm(xy-stop)>d_min); %value=0 cind punctul nu mai este in drept. curent sau cind a atins punctul de stop
isterminal = 1; %terminarea integrarii
direction = -1; %cind value trece din 1 in 0 (scade) - iesim dintr-un poligon sau ajungem linga stop
