function [timp,poz,vitez]=traseu_pas_cst(P0,coord,g_virfuri,stop,d_min,dt)
%functie pt gasirea traseului mobilului in dreptunghiul curent, avind valorile vector field-ului la virfuri
%integrare cu pas de timp constant
%date intrare:
%dt-pasul de timp
%P0-pozitia initiala (pt. dreptunghiul curent)
%vectorul "coord" contine x1,x2,y1,y2 - coordonatele virfurilor dreptunghiului curent (scalari)
%g_virfuri - matrice cu 2 linii ce contine valorile v.f. la virfurile drept. curent (vectori cu 2 elemente)
%in ordinea: g11-colt stinga-jos, g21-colt dreapta-jos, g22-colt dreapta-sus, g12-colt stinga-sus
%stop-coordonatele punctului de stop
%d_min-distanta minima considerata (pt a ne opri cind sintem in apropierea punctului de stop) 
%ult_dr-daca sintem in ultimul dreptunghi = 1, altfel 0 (se schimba conditia de oprire a integrarii)

%date iesire:
%timp-valorile timpului (relative la drept.) (0 este timpul initial in dreptunghiul curent)
%poz-pozitiile mobilului (matrice cu 2 linii) la momentele din vect. timp
%vitez-viteza mobilului (matrice cu 2 linii) la momentele de timp

x1=coord(1);
x2=coord(2);
y1=coord(3);
y2=coord(4);
coord_dr=[x1 x2 x2 x1;y1 y1 y2 y2]; %coordonatele dreptunghiului

g11=g_virfuri(:,1);
g21=g_virfuri(:,2);
g22=g_virfuri(:,3);
g12=g_virfuri(:,4);

xy(1,:)=P0(1);
xy(2,:)=P0(2);
dxdy=((x2-xy(1))*(y2-xy(2))*g11+(x2-xy(1))*(xy(2)-y1)*g12+(xy(1)-x1)*(y2-xy(2))*g21+(xy(1)-x1)*(xy(2)-y1)*g22)/((x2-x1)*(y2-y1));

i=1; %pozitia, viteza si timpul la inceput
timp(i)=0;
poz(:,i)=P0;
vitez(:,i)=dxdy;

while (inpolygon(xy(1),xy(2),coord_dr(1,:),coord_dr(2,:)) & norm(xy-stop)>d_min) %sintem indrept curent si nu am atins stop
    i=i+1;
    xy=xy+dxdy*dt;
    dxdy=((x2-xy(1))*(y2-xy(2))*g11+(x2-xy(1))*(xy(2)-y1)*g12+(xy(1)-x1)*(y2-xy(2))*g21+(xy(1)-x1)*(xy(2)-y1)*g22)/((x2-x1)*(y2-y1));

    timp(i)=timp(i-1)+dt;
    poz(:,i)=xy;
    vitez(:,i)=dxdy;
end
