function G=alege_g_dir_par(coord,dir,A,b,stop)
%functie pt alegerea valorilor vector field-ului (g111,...) la virfurile dreptunghiurilor
%vom folosi funcita linprog - minimizare a proiectiei unui vector pe o directie, cu diferite restrictii
%G (de tip cell) va contine, in elemetul i (i=1:nr_p), o matrice cu valorile
%g111,g112,g122,g121,g221,g211,g212,g222 pt paralep i din cale
%coord=matrice cu 6 coloane, cu linii de forma [x1,x2,y1,y2,z1,z2]
%dir=vector linie, care arata in ce directie iesim
%A,b - matricea, resp vect vare caracterizeaza orice punct X din interiorul U
%U-setul convex ce limiteaza vectorii viteza (AX<=b)
%stop-coordonatele punctului de stop (pt a alege val. g in ultimul drept.)

nr_p=length(dir);
G=cell(1,nr_p);
l_x=(coord(:,2)-coord(:,1))';
l_y=(coord(:,4)-coord(:,3))';
l_z=(coord(:,6)-coord(:,5))';
nx_min=min(l_x)/5;
ny_min=min(l_y)/5;
nz_min=min(l_z)/5;


D1=[0 1 0;0 0 0;0 0 -1]; %matrici pt calculul unui vector cu directia [d1;d2;d3]
D2=[-1 0 0;0 0 1;0 0 0]; %X are directia d daca [D1*d D2*d D3*d]X=[0;0;0]
D3=[0 0 0;0 -1 0;1 0 0];
Z=[0;0;0];

U111=[-1 0 0;0 -1 0;0 0 -1]; %pt a cauta un punct cu vx>0,vy>0,vz>0
U112=[-1 0 0;0 -1 0;0 0 1];
U122=[-1 0 0;0 1 0;0 0 1];
U121=[-1 0 0;0 1 0;0 0 -1];
U221=[1 0 0;0 1 0;0 0 -1];
U211=[1 0 0;0 -1 0;0 0 -1];
U212=[1 0 0;0 -1 0;0 0 1];
U222=[1 0 0;0 1 0;0 0 1];

opt=optimset('Display','off'); %pt ca functia de optimizare sa nu afiseze nimic

for i=1:nr_p-1
    dir_c=dir(i); %directia in care parasim drept. curent
    switch dir_c
        case 1 %parasim par i spre U
            nz=l_z(i);
            j=i+1;
            while (j<nr_p) & (dir(j)==dir_c)
                nz=nz+l_z(j);
                j=j+1;
            end
            if dir(j)==2 %din drept. j se merge L
                d111=-[nx_min;ny_min;nz];
                d121=-[nx_min;-ny_min;nz];
                d221=-[-l_x(j);-ny_min;nz];
                d211=-[-l_x(j);ny_min;nz];
            elseif dir(j)==3 %F
                d111=-[nx_min;l_y(j);nz];
                d121=-[nx_min;-ny_min;nz];
                d221=-[-nx_min;-ny_min;nz];
                d211=-[-nx_min;l_y(j);nz];
            elseif dir(j)==5 %R
                d111=-[l_x(j);ny_min;nz];
                d121=-[l_x(j);-ny_min;nz];
                d221=-[-nx_min;-ny_min;nz];
                d211=-[-nx_min;ny_min;nz];
            elseif dir(j)==6 %B
                d111=-[nx_min;ny_min;nz];
                d121=-[nx_min;-l_y(j);nz];
                d221=-[-nx_min;-l_y(j);nz];
                d211=-[-nx_min;ny_min;nz];
            else %dir(j)=0 - drept. tinta
                d111=-[nx_min;ny_min;nz];
                d121=-[nx_min;-ny_min;nz];
                d221=-[-nx_min;-ny_min;nz];
                d211=-[-nx_min;ny_min;nz];
            end
            g111=linprog(d111,[A;U111],[b;Z],[],[],[],[],[],opt);
            g121=linprog(d121,[A;U121],[b;Z],[],[],[],[],[],opt);
            g221=linprog(d221,[A;U221],[b;Z],[],[],[],[],[],opt);
            g211=linprog(d211,[A;U211],[b;Z],[],[],[],[],[],opt);
            G{i}=[g111 Z Z g121 g221 g211 Z Z];
        case 2 %parasim spre L
            nx=l_x(i);
            j=i+1;
            while (j<nr_p) & (dir(j)==dir_c)
                nx=nx+l_x(j);
                j=j+1;
            end
            if dir(j)==1 %U
                d221=-[-nx;-ny_min;l_z(j)];
                d211=-[-nx;ny_min;l_z(j)];
                d212=-[-nx;ny_min;-nz_min];
                d222=-[-nx;-ny_min;-nz_min];
            elseif dir(j)==3 %F
                d221=-[-nx;-ny_min;nz_min];
                d211=-[-nx;l_y(j);nz_min];
                d212=-[-nx;l_y(j);-nz_min];
                d222=-[-nx;-ny_min;-nz_min];
            elseif dir(j)==4 %D
                d221=-[-nx;-ny_min;nz_min];
                d211=-[-nx;ny_min;nz_min];
                d212=-[-nx;ny_min;-l_z(j)];
                d222=-[-nx;-ny_min;-l_z(j)];
            elseif dir(j)==6 %B
                d221=-[-nx;-l_y(j);nz_min];
                d211=-[-nx;ny_min;nz_min];
                d212=-[-nx;ny_min;-nz_min];
                d222=-[-nx;-l_y(j);-nz_min];
            else
                d221=-[-nx;-ny_min;nz_min];
                d211=-[-nx;ny_min;nz_min];
                d212=-[-nx;ny_min;-nz_min];
                d222=-[-nx;-ny_min;-nz_min];
            end
            g221=linprog(d221,[A;U221],[b;Z],[],[],[],[],[],opt);
            g211=linprog(d211,[A;U211],[b;Z],[],[],[],[],[],opt);
            g212=linprog(d212,[A;U212],[b;Z],[],[],[],[],[],opt);
            g222=linprog(d222,[A;U222],[b;Z],[],[],[],[],[],opt);
            G{i}=[Z Z Z Z g221 g211 g212 g222];
        case 3 %F
            ny=l_y(i);
            j=i+1;
            while (j<nr_p) & (dir(j)==dir_c)
                ny=ny+l_y(j);
                j=j+1;
            end
            if dir(j)==1 %U
                d111=-[nx_min;ny;l_z(j)];
                d112=-[nx_min;ny;-nz_min];
                d212=-[-nx_min;ny;-nz_min];
                d211=-[-nx_min;ny;l_z(j)];
            elseif dir(j)==2 %L
                d111=-[nx_min;ny;nz_min];
                d112=-[nx_min;ny;-nz_min];
                d212=-[-l_x(j);ny;-nz_min];
                d211=-[-l_x(j);ny;nz_min];
            elseif dir(j)==4 %D
                d111=-[nx_min;ny;nz_min];
                d112=-[nx_min;ny;-l_z(j)];
                d212=-[-nx_min;ny;-l_z(j)];
                d211=-[-nx_min;ny;nz_min];
            elseif dir(j)==5 %R
                d111=-[l_x(j);ny;nz_min];
                d112=-[l_x(j);ny;-nz_min];
                d212=-[-nx_min;ny;-nz_min];
                d211=-[-nx_min;ny;nz_min];
            else
                d111=-[nx_min;ny;nz_min];
                d112=-[nx_min;ny;-nz_min];
                d212=-[-nx_min;ny;-nz_min];
                d211=-[-nx_min;ny;nz_min];
            end
            g111=linprog(d111,[A;U111],[b;Z],[],[],[],[],[],opt);
            g112=linprog(d112,[A;U112],[b;Z],[],[],[],[],[],opt);
            g212=linprog(d212,[A;U212],[b;Z],[],[],[],[],[],opt);
            g211=linprog(d211,[A;U211],[b;Z],[],[],[],[],[],opt);
            G{i}=[g111 g112 Z Z Z g211 g212 Z];
        case 4 %D
            nz=l_z(i);
            j=i+1;
            while (j<nr_p) & (dir(j)==dir_c)
                nz=nz+l_z(j);
                j=j+1;
            end
            if dir(j)==2 %L
                d112=-[nx_min;ny_min;-nz];
                d122=-[nx_min;-ny_min;-nz];
                d222=-[-l_x(j);-ny_min;-nz];
                d212=-[-l_x(j);ny_min;-nz];
            elseif dir(j)==3 %F
                d112=-[nx_min;l_y(j);-nz];
                d122=-[nx_min;-ny_min;-nz];
                d222=-[-nx_min;-ny_min;-nz];
                d212=-[-nx_min;l_y(j);-nz];
            elseif dir(j)==5 %R
                d112=-[l_x(j);ny_min;-nz];
                d122=-[l_x(j);-ny_min;-nz];
                d222=-[-nx_min;-ny_min;-nz];
                d212=-[-nx_min;ny_min;-nz];
            elseif dir(j)==6 %B
                d112=-[nx_min;ny_min;-nz];
                d122=-[nx_min;-l_y(j);-nz];
                d222=-[-nx_min;-l_y(j);-nz];
                d212=-[-nx_min;ny_min;-nz];
            else
                d112=-[nx_min;ny_min;-nz];
                d122=-[nx_min;-ny_min;-nz];
                d222=-[-nx_min;-ny_min;-nz];
                d212=-[-nx_min;ny_min;-nz];
            end
            g112=linprog(d112,[A;U112],[b;Z],[],[],[],[],[],opt);
            g122=linprog(d122,[A;U122],[b;Z],[],[],[],[],[],opt);
            g222=linprog(d222,[A;U222],[b;Z],[],[],[],[],[],opt);
            g212=linprog(d212,[A;U212],[b;Z],[],[],[],[],[],opt);
            G{i}=[Z g112 g122 Z Z Z g212 g222];
        case 5 %R
            nx=l_x(i);
            j=i+1;
            while (j<nr_p) & (dir(j)==dir_c)
                nx=nx+l_x(j);
                j=j+1;
            end
            if dir(j)==1 %U
                d121=-[nx;-ny_min;l_z(j)];
                d111=-[nx;ny_min;l_z(j)];
                d112=-[nx;ny_min;-nz_min];
                d122=-[nx;-ny_min;-nz_min];
            elseif dir(j)==3 %F
                d121=-[nx;-ny_min;nz_min];
                d111=-[nx;l_y(j);nz_min];
                d112=-[nx;l_y(j);-nz_min];
                d122=-[nx;-ny_min;-nz_min];
            elseif dir(j)==4 %D
                d121=-[nx;-ny_min;nz_min];
                d111=-[nx;ny_min;nz_min];
                d112=-[nx;ny_min;-l_z(j)];
                d122=-[nx;-ny_min;-l_z(j)];
            elseif dir(j)==6 %B
                d121=-[nx;-l_y(j);nz_min];
                d111=-[nx;ny_min;nz_min];
                d112=-[nx;ny_min;-nz_min];
                d122=-[nx;-l_y(j);-nz_min];
            else
                d121=-[nx;-ny_min;nz_min];
                d111=-[nx;ny_min;nz_min];
                d112=-[nx;ny_min;-nz_min];
                d122=-[nx;-ny_min;-nz_min];
            end
            g121=linprog(d121,[A;U121],[b;Z],[],[],[],[],[],opt);
            g111=linprog(d111,[A;U111],[b;Z],[],[],[],[],[],opt);
            g112=linprog(d112,[A;U112],[b;Z],[],[],[],[],[],opt);
            g122=linprog(d122,[A;U122],[b;Z],[],[],[],[],[],opt);
            G{i}=[g111 g112 g122 g121 Z Z Z Z];
        case 6 %B
            ny=l_y(i);
            j=i+1;
            while (j<nr_p) & (dir(j)==dir_c)
                ny=ny+l_y(j);
                j=j+1;
            end
            if dir(j)==1 %U
                d121=-[nx_min;-ny;l_z(j)];
                d122=-[nx_min;-ny;-nz_min];
                d222=-[-nx_min;-ny;-nz_min];
                d221=-[-nx_min;-ny;l_z(j)];
            elseif dir(j)==2 %L
                d121=-[nx_min;-ny;nz_min];
                d122=-[nx_min;-ny;-nz_min];
                d222=-[-l_x(j);-ny;-nz_min];
                d221=-[-l_x(j);-ny;nz_min];
            elseif dir(j)==4 %D
                d121=-[nx_min;-ny;nz_min];
                d122=-[nx_min;-ny;-l_z(j)];
                d222=-[-nx_min;-ny;-l_z(j)];
                d221=-[-nx_min;-ny;nz_min];
            elseif dir(j)==5 %R
                d121=-[l_x(j);-ny;nz_min];
                d122=-[l_x(j);-ny;-nz_min];
                d222=-[-nx_min;-ny;-nz_min];
                d221=-[-nx_min;-ny;nz_min];
            else
                d121=-[nx_min;-ny;nz_min];
                d122=-[nx_min;-ny;-nz_min];
                d222=-[-nx_min;-ny;-nz_min];
                d221=-[-nx_min;-ny;nz_min];
            end
            g121=linprog(d121,[A;U121],[b;Z],[],[],[],[],[],opt);
            g122=linprog(d122,[A;U122],[b;Z],[],[],[],[],[],opt);
            g222=linprog(d222,[A;U222],[b;Z],[],[],[],[],[],opt);
            g221=linprog(d221,[A;U221],[b;Z],[],[],[],[],[],opt);
            G{i}=[Z Z g122 g121 g221 Z Z g222];
    end
end


%cautam punctele de schimbare de directie si alegem valorile g in ele
dir(nr_p+1)=0;
for i=2:(nr_p-1)
    if dir(i-1)==1 & dir(i)==2 %am intrat in drept i dinspre D si iesim spre L
        d=[0;0;1];
        g111=linprog(-d,[A;U111],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g121=linprog(-d,[A;U121],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,1)=g111;
        G{i}(:,4)=g121;
        G{i+1}(:,6)=g111;
        G{i+1}(:,5)=g121;
        if dir(i+1)==3
            G{i+2}(:,6)=g121;
        elseif dir(i+1)==6
            G{i+2}(:,5)=g111;
        end
    elseif dir(i-1)==1 & dir(i)==3
        d=[0;0;1];
        g221=linprog(-d,[A;U221],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g121=linprog(-d,[A;U121],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,5)=g221;
        G{i}(:,4)=g121;
        G{i+1}(:,6)=g221;
        G{i+1}(:,1)=g121;
        if dir(i+1)==2
            G{i+2}(:,6)=g121;
        elseif dir(i+1)==5
            G{i+2}(:,1)=g221;
        end
    elseif dir(i-1)==1 & dir(i)==5
        d=[0;0;1];
        g221=linprog(-d,[A;U221],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g211=linprog(-d,[A;U211],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,5)=g221;
        G{i}(:,6)=g211;
        G{i+1}(:,4)=g221;
        G{i+1}(:,1)=g211;
        if dir(i+1)==6
            G{i+2}(:,4)=g211;
        elseif dir(i+1)==3
            G{i+2}(:,1)=g221;
        end
    elseif dir(i-1)==1 & dir(i)==6
        d=[0;0;1];
        g111=linprog(-d,[A;U111],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g211=linprog(-d,[A;U211],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,1)=g111;
        G{i}(:,6)=g211;
        G{i+1}(:,4)=g111;
        G{i+1}(:,5)=g211;
        if dir(i+1)==5
            G{i+2}(:,4)=g211;
        elseif dir(i+1)==2
            G{i+2}(:,5)=g111;
        end
    
    elseif dir(i-1)==2 & dir(i)==1
        d=[-1;0;0];
        g212=linprog(-d,[A;U212],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g222=linprog(-d,[A;U222],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,7)=g212;
        G{i}(:,8)=g222;
        G{i+1}(:,6)=g212;
        G{i+1}(:,5)=g222;
        if dir(i+1)==3
            G{i+2}(:,6)=g222;
        elseif dir(i+1)==6
            G{i+2}(:,5)=g212;
        end
    elseif dir(i-1)==2 & dir(i)==3
        d=[-1;0;0];
        g221=linprog(-d,[A;U221],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g222=linprog(-d,[A;U222],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,5)=g221;
        G{i}(:,8)=g222;
        G{i+1}(:,6)=g221;
        G{i+1}(:,7)=g222;
        if dir(i+1)==1
            G{i+2}(:,6)=g222;
        elseif dir(i+1)==4
            G{i+2}(:,7)=g221;
        end
    elseif dir(i-1)==2 & dir(i)==4
        d=[-1;0;0];
        g221=linprog(-d,[A;U221],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g211=linprog(-d,[A;U211],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,5)=g221;
        G{i}(:,6)=g211;
        G{i+1}(:,8)=g221;
        G{i+1}(:,7)=g211;
        if dir(i+1)==6
            G{i+2}(:,8)=g211;
        elseif dir(i+1)==3
            G{i+2}(:,7)=g221;
        end
    elseif dir(i-1)==2 & dir(i)==6
        d=[-1;0;0];
        g212=linprog(-d,[A;U212],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g211=linprog(-d,[A;U211],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,7)=g212;
        G{i}(:,6)=g211;
        G{i+1}(:,8)=g212;
        G{i+1}(:,5)=g211;
        if dir(i+1)==4
            G{i+2}(:,8)=g211;
        elseif dir(i+1)==1
            G{i+2}(:,5)=g212;
        end
    
    elseif dir(i-1)==3 & dir(i)==1
        d=[0;1;0];
        g112=linprog(-d,[A;U112],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g212=linprog(-d,[A;U212],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,2)=g112;
        G{i}(:,7)=g212;
        G{i+1}(:,1)=g112;
        G{i+1}(:,6)=g212;
        if dir(i+1)==2
            G{i+2}(:,6)=g112;
        elseif dir(i+1)==5
            G{i+2}(:,1)=g212;
        end
    elseif dir(i-1)==3 & dir(i)==2
        d=[0;1;0];
        g112=linprog(-d,[A;U112],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g111=linprog(-d,[A;U111],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,2)=g112;
        G{i}(:,1)=g111;
        G{i+1}(:,7)=g112;
        G{i+1}(:,6)=g111;
        if dir(i+1)==1
            G{i+2}(:,6)=g112;
        elseif dir(i+1)==4
            G{i+2}(:,7)=g111;
        end
    elseif dir(i-1)==3 & dir(i)==4
        d=[0;1;0];
        g211=linprog(-d,[A;U211],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g111=linprog(-d,[A;U111],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,6)=g211;
        G{i}(:,1)=g111;
        G{i+1}(:,7)=g211;
        G{i+1}(:,2)=g111;
        if dir(i+1)==5
            G{i+2}(:,2)=g211;
        elseif dir(i+1)==2
            G{i+2}(:,7)=g111;
        end
    elseif dir(i-1)==3 & dir(i)==5
        d=[0;1;0];
        g211=linprog(-d,[A;U211],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g212=linprog(-d,[A;U212],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,6)=g211;
        G{i}(:,7)=g212;
        G{i+1}(:,1)=g211;
        G{i+1}(:,2)=g212;
        if dir(i+1)==4
            G{i+2}(:,2)=g211;
        elseif dir(i+1)==1
            G{i+2}(:,1)=g212;
        end
    
    elseif dir(i-1)==4 & dir(i)==2
        d=[0;0;-1];
        g112=linprog(-d,[A;U112],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g122=linprog(-d,[A;U122],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,2)=g112;
        G{i}(:,3)=g122;
        G{i+1}(:,7)=g112;
        G{i+1}(:,8)=g122;
        if dir(i+1)==3
            G{i+2}(:,7)=g122;
        elseif dir(i+1)==6
            G{i+2}(:,8)=g112;
        end
    elseif dir(i-1)==4 & dir(i)==3
        d=[0;0;-1];
        g222=linprog(-d,[A;U222],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g122=linprog(-d,[A;U122],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,8)=g222;
        G{i}(:,3)=g122;
        G{i+1}(:,7)=g222;
        G{i+1}(:,2)=g122;
        if dir(i+1)==2
            G{i+2}(:,7)=g122;
        elseif dir(i+1)==5
            G{i+2}(:,2)=g222;
        end
    elseif dir(i-1)==4 & dir(i)==5
        d=[0;0;-1];
        g222=linprog(-d,[A;U222],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g212=linprog(-d,[A;U212],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,8)=g222;
        G{i}(:,7)=g212;
        G{i+1}(:,3)=g222;
        G{i+1}(:,2)=g212;
        if dir(i+1)==6
            G{i+2}(:,3)=g212;
        elseif dir(i+1)==3
            G{i+2}(:,2)=g222;
        end
    elseif dir(i-1)==4 & dir(i)==6
        d=[0;0;-1];
        g112=linprog(-d,[A;U112],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g212=linprog(-d,[A;U212],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,2)=g112;
        G{i}(:,7)=g212;
        G{i+1}(:,3)=g112;
        G{i+1}(:,8)=g212;
        if dir(i+1)==5
            G{i+2}(:,3)=g212;
        elseif dir(i+1)==2
            G{i+2}(:,8)=g112;
        end
    
    elseif dir(i-1)==5 & dir(i)==1
        d=[1;0;0];
        g112=linprog(-d,[A;U112],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g122=linprog(-d,[A;U122],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,2)=g112;
        G{i}(:,3)=g122;
        G{i+1}(:,1)=g112;
        G{i+1}(:,4)=g122;
        if dir(i+1)==3
            G{i+2}(:,1)=g122;
        elseif dir(i+1)==6
            G{i+2}(:,4)=g112;
        end
    elseif dir(i-1)==5 & dir(i)==3
        d=[1;0;0];
        g121=linprog(-d,[A;U121],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g122=linprog(-d,[A;U122],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,4)=g121;
        G{i}(:,3)=g122;
        G{i+1}(:,1)=g121;
        G{i+1}(:,2)=g122;
        if dir(i+1)==1
            G{i+2}(:,1)=g122;
        elseif dir(i+1)==4
            G{i+2}(:,2)=g121;
        end
    elseif dir(i-1)==5 & dir(i)==4
        d=[1;0;0];
        g121=linprog(-d,[A;U121],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g111=linprog(-d,[A;U111],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,4)=g121;
        G{i}(:,1)=g111;
        G{i+1}(:,3)=g121;
        G{i+1}(:,2)=g111;
        if dir(i+1)==6
            G{i+2}(:,3)=g111;
        elseif dir(i+1)==3
            G{i+2}(:,2)=g121;
        end
    elseif dir(i-1)==5 & dir(i)==6
        d=[1;0;0];
        g112=linprog(-d,[A;U112],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g111=linprog(-d,[A;U111],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,2)=g112;
        G{i}(:,1)=g111;
        G{i+1}(:,3)=g112;
        G{i+1}(:,4)=g111;
        if dir(i+1)==4
            G{i+2}(:,3)=g111;
        elseif dir(i+1)==1
            G{i+2}(:,4)=g112;
        end
    
    elseif dir(i-1)==6 & dir(i)==1
        d=[0;-1;0];
        g122=linprog(-d,[A;U122],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g222=linprog(-d,[A;U222],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,3)=g122;
        G{i}(:,8)=g222;
        G{i+1}(:,4)=g122;
        G{i+1}(:,5)=g222;
        if dir(i+1)==2
            G{i+2}(:,5)=g122;
        elseif dir(i+1)==5
            G{i+2}(:,4)=g222;
        end
    elseif dir(i-1)==6 & dir(i)==2
        d=[0;-1;0];
        g122=linprog(-d,[A;U122],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g121=linprog(-d,[A;U121],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,3)=g122;
        G{i}(:,4)=g121;
        G{i+1}(:,8)=g122;
        G{i+1}(:,5)=g121;
        if dir(i+1)==1
            G{i+2}(:,5)=g122;
        elseif dir(i+1)==4
            G{i+2}(:,8)=g121;
        end
    elseif dir(i-1)==6 & dir(i)==4
        d=[0;-1;0];
        g221=linprog(-d,[A;U221],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g121=linprog(-d,[A;U121],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,5)=g221;
        G{i}(:,4)=g121;
        G{i+1}(:,8)=g221;
        G{i+1}(:,3)=g121;
        if dir(i+1)==5
            G{i+2}(:,3)=g221;
        elseif dir(i+1)==2
            G{i+2}(:,8)=g121;
        end
    elseif dir(i-1)==6 & dir(i)==5
        d=[0;-1;0];
        g221=linprog(-d,[A;U221],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        g222=linprog(-d,[A;U222],[b;Z],[D1*d D2*d D3*d],Z,[],[],[],opt);
        G{i}(:,5)=g221;
        G{i}(:,8)=g222;
        G{i+1}(:,4)=g221;
        G{i+1}(:,3)=g222;
        if dir(i+1)==4
            G{i+2}(:,3)=g221;
        elseif dir(i+1)==1
            G{i+2}(:,4)=g222;
        end
    
    end
end


%asignarea valorilor g pt ultimul dreptunghi (formulele in caiet)
d111=stop-coord(nr_p,[1 3 5])'; %directiile lui g11,... (NU directiile de maximizare)
d112=stop-coord(nr_p,[1 3 6])';
d122=stop-coord(nr_p,[1 4 6])';
d121=stop-coord(nr_p,[1 4 5])';
d221=stop-coord(nr_p,[2 4 5])';
d211=stop-coord(nr_p,[2 3 5])';
d212=stop-coord(nr_p,[2 3 6])';
d222=stop-coord(nr_p,[2 4 6])';

%aflarea valorii scalare lambda maxim (limitat de setul U) (minimul dintre valorile lam. maxime pt g11,...)
lam1=linprog(-d111,[A;U111],[b;Z],[D1*d111 D2*d111 D3*d111],Z,[],[],[],opt); %aflam lambda max. pt g11,...
lam1=norm(lam1)/norm(d111);
lam2=linprog(-d112,[A;U112],[b;Z],[D1*d112 D2*d112 D3*d112],Z,[],[],[],opt);
lam2=norm(lam2)/norm(d112);
lam3=linprog(-d122,[A;U122],[b;Z],[D1*d122 D2*d122 D3*d122],Z,[],[],[],opt);
lam3=norm(lam3)/norm(d122);
lam4=linprog(-d121,[A;U121],[b;Z],[D1*d121 D2*d121 D3*d121],Z,[],[],[],opt);
lam4=norm(lam4)/norm(d121);
lam5=linprog(-d221,[A;U221],[b;Z],[D1*d221 D2*d221 D3*d221],Z,[],[],[],opt);
lam5=norm(lam5)/norm(d221);
lam6=linprog(-d211,[A;U211],[b;Z],[D1*d211 D2*d211 D3*d211],Z,[],[],[],opt);
lam6=norm(lam6)/norm(d211);
lam7=linprog(-d212,[A;U212],[b;Z],[D1*d212 D2*d212 D3*d212],Z,[],[],[],opt);
lam7=norm(lam7)/norm(d212);
lam8=linprog(-d222,[A;U222],[b;Z],[D1*d222 D2*d222 D3*d222],Z,[],[],[],opt);
lam8=norm(lam8)/norm(d222);

lam=min([lam1 lam2 lam3 lam4 lam5 lam6 lam7 lam8]);
G{nr_p}=lam*[d111 d112 d122 d121 d221 d211 d212 d222];


%parcurgem calea si setam g la virfurile la care nu sint (de la paralep. urmator) pt a asigura o traiectorie smooth
for i=2:nr_p
    switch(dir(i-1)) %directia dinspre care am intrat in i
        case 1 %am intrat dinspre D
            if isequal(G{i-1}(:,2),Z)
                G{i-1}(:,2)=G{i}(:,1);
            else
                G{i}(:,1)=G{i-1}(:,2);
            end
            if isequal(G{i-1}(:,3),Z)
                G{i-1}(:,3)=G{i}(:,4);
            else
                G{i}(:,4)=G{i-1}(:,3);
            end
            if isequal(G{i-1}(:,8),Z)
                G{i-1}(:,8)=G{i}(:,5);
            else
                G{i}(:,5)=G{i-1}(:,8);
            end
            if isequal(G{i-1}(:,7),Z)
                G{i-1}(:,7)=G{i}(:,6);
            else
                G{i}(:,6)=G{i-1}(:,7);
            end
        case 2 %dinspre R
            if isequal(G{i-1}(:,1),Z)
                G{i-1}(:,1)=G{i}(:,6);
            else
                G{i}(:,6)=G{i-1}(:,1);
            end
            if isequal(G{i-1}(:,2),Z)
                G{i-1}(:,2)=G{i}(:,7);
            else
                G{i}(:,7)=G{i-1}(:,2);
            end
            if isequal(G{i-1}(:,3),Z)
                G{i-1}(:,3)=G{i}(:,8);
            else
                G{i}(:,8)=G{i-1}(:,3);
            end
            if isequal(G{i-1}(:,4),Z)
                G{i-1}(:,4)=G{i}(:,5);
            else
                G{i}(:,5)=G{i-1}(:,4);
            end
        case 3 %dinspre B
            if isequal(G{i-1}(:,3),Z)
                G{i-1}(:,3)=G{i}(:,2);
            else
                G{i}(:,2)=G{i-1}(:,3);
            end
            if isequal(G{i-1}(:,4),Z)
                G{i-1}(:,4)=G{i}(:,1);
            else
                G{i}(:,1)=G{i-1}(:,4);
            end
            if isequal(G{i-1}(:,5),Z)
                G{i-1}(:,5)=G{i}(:,6);
            else
                G{i}(:,6)=G{i-1}(:,5);
            end
            if isequal(G{i-1}(:,8),Z)
                G{i-1}(:,8)=G{i}(:,7);
            else
                G{i}(:,7)=G{i-1}(:,8);
            end
        case 4 %dinspre U
            if isequal(G{i-1}(:,1),Z)
                G{i-1}(:,1)=G{i}(:,2);
            else
                G{i}(:,2)=G{i-1}(:,1);
            end
            if isequal(G{i-1}(:,4),Z)
                G{i-1}(:,4)=G{i}(:,3);
            else
                G{i}(:,3)=G{i-1}(:,4);
            end
            if isequal(G{i-1}(:,5),Z)
                G{i-1}(:,5)=G{i}(:,8);
            else
                G{i}(:,8)=G{i-1}(:,5);
            end
            if isequal(G{i-1}(:,6),Z)
                G{i-1}(:,6)=G{i}(:,7);
            else
                G{i}(:,7)=G{i-1}(:,6);
            end
        case 5 %dinspre L
            if isequal(G{i-1}(:,5),Z)
                G{i-1}(:,5)=G{i}(:,4);
            else
                G{i}(:,4)=G{i-1}(:,5);
            end
            if isequal(G{i-1}(:,6),Z)
                G{i-1}(:,6)=G{i}(:,1);
            else
                G{i}(:,1)=G{i-1}(:,6);
            end
            if isequal(G{i-1}(:,7),Z)
                G{i-1}(:,7)=G{i}(:,2);
            else
                G{i}(:,2)=G{i-1}(:,7);
            end
            if isequal(G{i-1}(:,8),Z)
                G{i-1}(:,8)=G{i}(:,3);
            else
                G{i}(:,3)=G{i-1}(:,8);
            end
        case 6 %dinspre F
            if isequal(G{i-1}(:,1),Z)
                G{i-1}(:,1)=G{i}(:,4);
            else
                G{i}(:,4)=G{i-1}(:,1);
            end
            if isequal(G{i-1}(:,2),Z)
                G{i-1}(:,2)=G{i}(:,3);
            else
                G{i}(:,3)=G{i-1}(:,2);
            end
            if isequal(G{i-1}(:,7),Z)
                G{i-1}(:,7)=G{i}(:,8);
            else
                G{i}(:,8)=G{i-1}(:,7);
            end
            if isequal(G{i-1}(:,6),Z)
                G{i-1}(:,6)=G{i}(:,5);
            else
                G{i}(:,5)=G{i-1}(:,6);
            end
    end
end

G{nr_p}=lam*[d111 d112 d122 d121 d221 d211 d212 d222]; %s-ar fi putut schimba (din cauza penult. par)
